@@ -34,7 +34,7 @@ def prepare_terraform_environment(data_dir):
     os.environ["TF_REGISTRY_CLIENT_TIMEOUT"] = "60"
     os.environ["TF_IN_AUTOMATION"] = "true"
     os.environ["TF_PLUGIN_CACHE_DIR"] = f"{os.path.expanduser('~')}/.terraform.d/plugin-cache"
-    os.environ["TF_DATA_DIR"] = data_dir
+    # os.environ["TF_DATA_DIR"] = data_dir
     if not os.path.exists(f"{os.path.expanduser('~')}/.terraform.d/plugin-cache"):
         os.makedirs(f"{os.path.expanduser('~')}/.terraform.d/plugin-cache")
 
@@ -57,11 +57,11 @@ class RundeckJobs(object):
         subprocess.run(command, cwd=cwd, check=check)
 
     def clone_rundeck_codebase(self, gitlab_deploy_token: str):
-        repository_directory = tempfile.mkdtemp()
-        self.run_command(["git", "clone", "--depth", "1",
-                          f"https://oauth2:{gitlab_deploy_token}@gitlab.zadapps.info/infrastructure/rundeck/rundeck.git",
-                          repository_directory], cwd="/tmp")
-        return repository_directory
+        with tempfile.TemporaryDirectory() as tmpdir:
+            self.run_command(["git", "clone", "--depth", "1",
+                              f"https://oauth2:{gitlab_deploy_token}@gitlab.zadapps.info/infrastructure/rundeck/rundeck.git",
+                              tmpdir], cwd="/tmp")
+            return tmpdir
 
     def search_uptimerobot(
             self,
@@ -437,20 +437,17 @@ class RundeckJobs(object):
         write_into_file(vars_file_content, vars_file_location)
 
         prepare_terraform_environment(config_dir_location)
+        self.run_command(["terraform", "init", "-input=false", "-reconfigure", "-force-copy",
+                          f"-backend-config", backend_config_file_location],
+                         cwd=terraform_code_dir, check=True)
         try:
             subprocess.run(["terraform", "workspace", "select", f"{fqdn}.build"],
                            cwd=terraform_code_dir, check=True)
-            self.run_command(["terraform", "init", "-input=false", "-reconfigure", "-force-copy",
-                              f"-backend-config", backend_config_file_location],
-                             cwd=terraform_code_dir, check=True)
         except subprocess.CalledProcessError:
             subprocess.run(["terraform", "workspace", "new", f"{fqdn}.build"],
                            cwd=terraform_code_dir, check=True)
-            self.run_command(["terraform", "init", "-input=false", "-reconfigure", "-force-copy",
-                              f"-backend-config", backend_config_file_location],
-                             cwd=terraform_code_dir, check=True)
 
-        plan_file_location = f"{config_dir_location}/config.plan"
+        plan_file_location = f"./config.plan"
 
         if deployment_action == "apply":
             self.run_command(
